@@ -1,11 +1,11 @@
 package Tie::Tools;
 
-# $Id: Tools.pm,v 1.1 2003/12/08 21:10:33 jonasbn Exp $
+# $Id: Tools.pm 1884 2007-10-29 21:25:10Z jonasbn $
 
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 1;
 
@@ -15,8 +15,6 @@ __END__;
 
 Tie::Tools - a collection of tying tools
 
-=cut
-
 =head1 DESCRIPTION
 
 Tie::Tools consist of several modules each in their own namespace.
@@ -49,7 +47,7 @@ Tie::Parent
 
 =head1 COPYRIGHT
 
-XML::Conf is free software and is released under the Artistic License.
+Tie::Tools is free software and is released under the Artistic License.
 See <http://www.perl.com/language/misc/Artistic.html> for details.
 
 =head1 AUTHOR
@@ -65,4 +63,8 @@ author.
 
 Jonas B. Nielsen <jonasbn@cpan.dk>
 
+=head1 ACKNOWLEDGEMENTS
+
+- patch from Brian Dowling resulting in release 1.06
+
 =cut
